aboutsummaryrefslogtreecommitdiff
path: root/gn3/computations/qtlreaper.py
diff options
context:
space:
mode:
authorFrederick Muriuki Muriithi2021-09-27 04:48:53 +0300
committerFrederick Muriuki Muriithi2021-09-27 04:48:53 +0300
commit19783a18c2bc7941fc5980e593f19fb1d18c3623 (patch)
treef3a6e241be3c6224b9647c8258c516a7b741a28c /gn3/computations/qtlreaper.py
parent8d9bc0f29ce9208306915b079818e6f0c31785e2 (diff)
downloadgenenetwork3-19783a18c2bc7941fc5980e593f19fb1d18c3623.tar.gz
Update terminology: `strain` to `sample`
Issue: https://github.com/genenetwork/gn-gemtext-threads/blob/main/topics/gn1-migration-to-gn2/clustering.gmi * Update the terminology used: use `sample` in place of `strain` according to Zachary's direction at https://github.com/genenetwork/genenetwork3/pull/37#issuecomment-926043306
Diffstat (limited to 'gn3/computations/qtlreaper.py')
-rw-r--r--gn3/computations/qtlreaper.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/gn3/computations/qtlreaper.py b/gn3/computations/qtlreaper.py
index 8b2893e..166d2dd 100644
--- a/gn3/computations/qtlreaper.py
+++ b/gn3/computations/qtlreaper.py
@@ -9,17 +9,17 @@ from typing import Union
from gn3.random import random_string
from gn3.settings import TMPDIR, REAPER_COMMAND
-def generate_traits_file(strains, trait_values, traits_filename):
+def generate_traits_file(samples, trait_values, traits_filename):
"""
Generate a traits file for use with `qtlreaper`.
PARAMETERS:
strains: A list of strains to use as the headers for the various columns.
trait_values: A list of lists of values for each trait and strain.
traits_filename: The tab-separated value to put the values in for
computation of QTLs.
"""
- header = "Trait\t{}\n".format("\t".join(strains))
+ header = "Trait\t{}\n".format("\t".join(samples))
data = (
[header] +
["{}\t{}\n".format(i+1, "\t".join([str(i) for i in t]))
@@ -9,17 +9,17 @@ from typing import Union
Generate a traits file for use with `qtlreaper`.
PARAMETERS:
- strains: A list of strains to use as the headers for the various columns.
- trait_values: A list of lists of values for each trait and strain.
+ samples: A list of samples to use as the headers for the various columns.
+ trait_values: A list of lists of values for each trait and sample.
traits_filename: The tab-separated value to put the values in for
computation of QTLs.